 
qualitymanager = {
	parseQuality : function(text) {
		// get quality name
		text = text.trim().replace(/[,.]+$/, '');
		var name = text.replace(/^\W+|\W+$/g, '');
		if (text.indexOf("(") > 0) {
			name = text.substring(0,text.indexOf("(")).trim();
		} else if (name.match(/^.+ ([VIX]+|\d+)$/) != null) {
			var lastSpace = name.lastIndexOf(" ");
			name = name.substring(0, lastSpace).trim();
		}
				
		// lookup quality instance from config, clone it
		name = name.toLowerCase();
		var newquality = qualitymanager.getRawQuality(name);
		
		// call parse method on new quality
		if (newquality !== undefined && newquality !== null) {
			newquality.parse(text);
			return newquality;
		} else {
			return null;
		}
	},
	
	fixXp : function(xp) {
		if (xp < 0) {
			return Math.floor(xp);
		} else {
			return Math.ceil(xp);
		}
	},
	
	getRawQuality : function(qname) {
		var quality = null;
		// get a copy of the default instance of this quality	
		var keys = config.supplimentQualities.getKeys();			
		for (k = 0; k < keys.length && quality == null; ++k) { // for each suppliment
			var qualities = config.supplimentQualities.getItem(keys[k]);
			if (qualities.length > 0) {
				for (var q = 0; q < qualities.length && quality == null; ++q) { // for each quality
					if(qualities[q]) {					
						if (qualities[q].name == qname) {
							quality = qualities[q];
						}
					}
				}
			}
		}
		return quality
	}

};

/*
 * Create a simple quality,
 * maxuses may be set to zero if there is no cap
 */
function Quality(name, xp, restrictions, options) {
	if (name) {
		this.name = name;
		this.xp = xp;
		this.restrictions = restrictions;
		this.details = "";
		if (options !== null) {
			this.options = options;
		} else {
			this.options = [];
		}
	} else {
		return null;
	}
}

Quality.prototype.clone = function() {
	var clone = new Quality(this.name, this.xp, this.restrictions, this.options);
	clone.details = this.details;
	return clone;
}

// each quality may have assigned to it a custom editMethod and renderMethod.

// edit a simple quality
Quality.prototype.edit = function() {};

// render a simple quality
Quality.prototype.render = function() {
	var output = "<span>";	
	output += "<em>" + this.name + "</em>";
	
	if (this.details && this.details !== "") {
		this.details = this.details.trim();
		// if details is just a roman numeral, don't put it in brackets
		if (this.details.match(/^([VIX]+|\d+)$/) != null) {
			output += " " + this.details;
		} else {
			output += " (" + this.details + ")";
		}
	}
	
	output += "</span>";
	return output;
};

Quality.prototype.getxp = function() {
	return qualitymanager.fixXp(this.xp);
};

Quality.prototype.makeused = function() {};

Quality.prototype.setdetails = function() {};

Quality.prototype.parse = function(text) {};


//simple quality
function SQuality(name, xp, restrictions, options) {
	this.base = Quality;
	this.base(name, xp, restrictions, options);
	this.use = "";
}
SQuality.prototype = new Quality();

SQuality.prototype.clone = function() {
	var clone = new SQuality(this.name, this.xp, this.restrictions, this.options);
	clone.use = this.use;
	clone.details = this.details;
	return clone;
}

SQuality.prototype.edit = function() {
	var output = "<div>"
	if (this.options && this.options.length > 0) {
		// if there is more than one option, allow selection
		output += npcutil.getListSelector("qopts", this.options, true, this.use);
	}
	output += "</div>";
	return output;
};

SQuality.prototype.updatefromform = function(formDivId) {
	if ($("#"+formDivId + " #qopts").length > 0) {
		this.use = $("#"+formDivId + " #qopts").val();
	}
};

SQuality.prototype.getxp = function() {
	if (this.options && this.options.length > 0) {
		// get index of use in options
		var index = -1;
		for (i = 0; i < this.options.length; ++i) {
			if (this.use == this.options[i]) {
				index = i;
			}
		}
		return qualitymanager.fixXp((index+1)*this.xp);
	} else {
		return qualitymanager.fixXp(this.xp);
	}
};

SQuality.prototype.makeused = function() {
	//set uses to 1 if none
	if (this.use === "" && $.isArray(this.options) && this.options.length > 0) {
		this.use = this.options[0];
	}
};

SQuality.prototype.setdetails = function() {	
	this.details = this.use;
};

SQuality.prototype.parse = function(text) {	
	if (text.indexOf("(") > 0) {
		// copy text from within the brackets into use
		this.use = text.substring(text.indexOf("(")+1, text.indexOf(")"));
	} else if (text.match(/^.+ ([VIX]+|\d+)$/) != null) {
		var lastSpace = text.lastIndexOf(" ");
		this.use = text.substring(lastSpace).trim();
	}
	this.setdetails();
};

//detail quality
function DQuality(name, xp, restrictions, options, maxuses) {
	this.base = Quality;
	this.base(name, xp, restrictions, options);
	this.maxuses = maxuses;
	if (maxuses === undefined || maxuses === null || maxuses === 0) {
	 this.maxuses = config.qualityDefaultMaxuses;
	}
	this.uses = [];
}
DQuality.prototype = new Quality();

DQuality.prototype.clone = function() {
	var clone = new DQuality(this.name, this.xp, this.restrictions, this.options, this.maxuses);
	clone.details = this.details;
	clone.uses = this.uses;
	return clone;
}

DQuality.prototype.edit = function() {
	var output = "<div>";
	
	for (var i = 0; i < this.maxuses; ++i) {
		
		if (i != 0) {
			output += "<hr/>";	
		}
				
		// if options provide a selector else provide a textbox
		var input;
		var id = "quse-"+i;
		// select current values
		var selected = null;
		if (i < this.uses.length) {
			selected = this.uses[i];
		}
		
		if (this.options && this.options.length > 0) {
			output += npcutil.getListSelector(id, this.options, true, selected);
		} else {
			output += "<input type='text' id='"+id;
			
			if (selected !== null) {
				output += "' value='" + selected;
			}
			output += "'/>";		
		}
	}
	
	output += "</div>";
	return output;
};

DQuality.prototype.updatefromform = function(formDivId) {
	for (var i = 0; i < this.maxuses; ++i) {
		var uid = "#"+formDivId + " #quse-"+i;
		if ($(uid).length) {
			this.uses[i] = $(uid).val();
		}
	}
};

DQuality.prototype.makeused = function() {
	//if no uses
	if (this.uses.length === 0) {
		//set one useade with first option if there else dummy text
		if (this.options !== null && this.options.length > 0) {
			this.uses.push(this.options[0]);
		} else {
			this.uses.push("unspecified");
		}
	}
};

DQuality.prototype.getxp = function() {
	var xp = 0;
	for (var u = 0; u < this.uses.length; ++u) {
		if (this.uses[u] !== "") {
			xp += this.xp;
		}
	}
	return qualitymanager.fixXp(xp);
};

DQuality.prototype.setdetails = function() {
	this.details = "";
	var sorteduses = [];
	for (var u = 0; u < this.uses.length; ++u) {
		if (this.uses[u] !== "") {
			sorteduses.push(this.uses[u]);
		}
	}
	sorteduses.sort();
	for (var d = 0; d < sorteduses.length; ++d) {
		if (d !== 0) {
			this.details += ", ";
		}
		this.details += npcutil.sanitizeCustomText(sorteduses[d]);
	}
};

DQuality.prototype.parse = function(text) {
	if (text.indexOf("(") > 0) {
		// add comma delimited items to this.uses
		this.uses = text.substring(text.indexOf("(")+1, text.lastIndexOf(")")).split(/\s*,\s*/);		
	}
	this.setdetails();
};

//fixed detail quality - as a dquality but with a fixed xp if there are any uses
function FDQuality(name, xp, restrictions, options, maxuses) {
	this.base = DQuality;
	this.base(name, xp, restrictions, options, maxuses);
	this.uses = [];
}
FDQuality.prototype = new DQuality();

FDQuality.prototype.clone = function() {
	var clone = new FDQuality(this.name, this.xp, this.restrictions, this.options, this.maxuses);
	clone.details = this.details;
	clone.uses = this.uses;
	return clone;
}

FDQuality.prototype.getxp = function() {
	var xp = 0;
	for (var u = 0; u < this.uses.length && xp == 0; ++u) {
		if (this.uses[u] !== "") {
			xp = this.xp;
		}
	}
	return qualitymanager.fixXp(xp);
};

//extended detail quality
function EDQuality(name, xp, restrictions, options, maxuses, values) {
	this.base = DQuality;
	this.base(name, xp, restrictions, options, maxuses);
	this.values = values;
	/*
	 * here each item in uses will itself be an array with two items. The first being
	 * the detail chosen the second being the value.
	 */
	this.uses = [];
}
EDQuality.prototype = new DQuality();

EDQuality.prototype.clone = function() {
	var clone = new EDQuality(this.name, this.xp, this.restrictions, this.options, this.maxuses, this.values);
	clone.details = this.details;
	clone.uses = this.uses;
	return clone;
}

EDQuality.prototype.makeused = function() {
	//if no uses
	if (this.uses.length === 0) {
		//set one useage with first option and first value if there else dummy text
		if (this.options !== null && this.options.length > 0) {
			this.uses.push([this.options[0], this.values[0]]);
		} else {
			this.uses.push(["unspecified", this.values[0]]);
		}
	}
};

EDQuality.prototype.getxp = function() {
	var xp = 0;
	for (var u = 0; u < this.uses.length; ++u) {
		var name = this.uses[u][0];
		var value = this.uses[u][1];
		if (name !== "") {
			var index = -1;
			for (i = 0; i < this.values.length; ++i) {
				if (value == this.values[i]) {
					index = i;
				}
			}
			xp += (index+1)*this.xp;
		}
	}
	return qualitymanager.fixXp(xp);
};

EDQuality.prototype.edit = function() {
	var output = "<div>";
		
	for (var i = 0; i < this.maxuses; ++i) {	
			
		if (i += 0) {
			output += "<hr/>";
		}
			
		// if options provide a selector else provide a textbox
		var input;
		var id = "quse-"+i;
		// select current values
		var selected = null;
		if (i < this.uses.length) {
			selected = this.uses[i];
		}
		
		if (this.options && this.options.length > 0) {
			if (selected !== null) {
				output += npcutil.getListSelector(id, this.options, true, selected[0]);
			} else {
				output += npcutil.getListSelector(id, this.options, true);
			}
		} else {
			output += "<input type='text' id='"+id;
			
			if (selected !== null) {
				output += "' value='" + selected[0];
			}
			output += "'>";
		}
		
		// add value selector
		var select = document.createElement('select');
		select.id = "qval-"+i;
		if (selected !== null) {
			output += npcutil.getListSelector("qval-"+i, this.values, false, selected[1]);
		} else {
			output += npcutil.getListSelector("qval-"+i, this.values, false);
		}
		
	}
	
	output += "</div>";
	
	return output;
};

EDQuality.prototype.updatefromform = function(formDivId) {
	for (var i = 0; i < this.maxuses; ++i) {		
		var oid = "#"+formDivId + " #quse-"+i;
		var vid = "#"+formDivId + " #qval-"+i;
		if ($(oid).length && $(vid).length) {
			this.uses[i] = [$(oid).val(), $(vid).val()];
		}
	}
};

EDQuality.prototype.setdetails = function() {
	this.details = "";
	var sorteduses = [];
	for (var u = 0; u < this.uses.length; ++u) {
		if (this.uses[u][0] !== "") {
			sorteduses.push(this.uses[u][0] + "---" + this.uses[u][1]);
		}
	}
	sorteduses.sort();
	for (var d = 0; d < sorteduses.length; ++d) {
		if (d !== 0) {
			this.details += ", ";
		}
		var qparts = sorteduses[d].split("---",2);
		this.details += npcutil.sanitizeCustomText(qparts[0]) + " " + npcutil.sanitizeCustomText(qparts[1]);
	}
};

EDQuality.prototype.parse = function(text) {
	if (text.indexOf("(") > 0) {
		// add comma delimited items to this.uses in name,value pairs
		var uses = text.substring(text.indexOf("(")+1, text.indexOf(")")).split(/\s*,\s+/g);
		for (var i = 0; i < uses.length; ++i) {
			var usetext = uses[i].trim();
			var splitpoint = usetext.lastIndexOf(" ");
			var use = [usetext.substring(0,splitpoint).trim(), usetext.substring(splitpoint).trim()]
			this.uses.push(use);
		}
	}
	this.setdetails();
};

//class for foil quality, needed because the xp can go negative or positive
function FoilSQuality(name, xp, restrictions, options) {
	this.base = SQuality;
	this.base(name, xp, restrictions, options);
}
FoilSQuality.prototype = new SQuality();

FoilSQuality.prototype.clone = function() {
	var clone = new FoilSQuality(this.name, this.xp, this.restrictions, this.options);
	clone.use = this.use;
	clone.details = this.details;
	return clone;
}

FoilSQuality.prototype.getxp = function() {
	return qualitymanager.fixXp(parseInt(this.use, 10));
};

//class for foil quality, needed because the xp can go negative or positive
function WingedFlightSQuality(name, xp, restrictions, options) {
	this.base = SQuality;
	this.base(name, xp, restrictions, options);
}
WingedFlightSQuality.prototype = new SQuality();

WingedFlightSQuality.prototype.clone = function() {
	var clone = new WingedFlightSQuality(this.name, this.xp, this.restrictions, this.options);
	clone.use = this.use;
	clone.details = this.details;
	return clone;
}

WingedFlightSQuality.prototype.getxp = function() {
	// get index of use in options
	var index = -1;
	for (i = 0; i < this.options.length; ++i) {
		if (this.use == this.options[i]) {
			index = i;
		}
	}
	var xptotal = (index+1)*this.xp;
	if (xptotal > 0) {
		return qualitymanager.fixXp(xptotal + 2);
	} else {
		return 0;
	}
};

//class for attribute qualities, needed because of the int difference for animals
function AttrEDQuality(name, xp, values) {
	this.base = EDQuality;
	this.base(name, xp, null, config.attributes, 6, values);
	this.uses=[["Str", 10], ["Dex", 10], ["Con", 10], ["Int", 10], ["Wis", 10], ["Cha", 10]];
	if (npc.animal) {
		this.uses=[["Str", 10], ["Dex", 10], ["Con", 10], ["Int", 2], ["Wis", 10], ["Cha", 10]];
	}
}
AttrEDQuality.prototype = new EDQuality();

AttrEDQuality.prototype.clone = function() {
	var clone = new AttrEDQuality(this.name, this.xp, this.values);
	clone.details = this.details;
	clone.uses = this.uses;
	return clone;
}

AttrEDQuality.prototype.isanimalint = function(attr) {
	if (npc.animal && attr === "Int") {
		return true;
	} else {
		return false;
	}	
};

AttrEDQuality.prototype.makeused = function() {};

AttrEDQuality.prototype.getxp = function() {
	var xp = 0;
	for (var u = 0; u < this.uses.length; ++u) {
		var name = this.uses[u][0];
		var value = this.uses[u][1];
		if (this.isanimalint(name)) {
			if (value != 2) {
				xp += value - 2;
			}
		} else {
			var index = -1;
			for (i = 0; i < this.values.length; ++i) {
				if (value == this.values[i]) {
					index = i;
				}
			}
			xp += index*this.xp;
		}
	}
	return qualitymanager.fixXp(xp);
};

AttrEDQuality.prototype.setdetails = function() {
	this.details = "";
	var first = true;
	for (var u = 0; u < this.uses.length; ++u) {
		var use = false;
		if (this.isanimalint(this.uses[u][0])) {
			if (this.uses[u][1] != 2) {
				use = true;
			}
		} else {
			if (this.uses[u][1] != 10) {
				use = true;
			}
		}
		if (use) {
			if (first) {
				first = false;
			} else {
				this.details += ", ";
			}
			this.details += this.uses[u][0] + " " + this.uses[u][1];
		}
	}
};

AttrEDQuality.prototype.edit = function() {
	var output = "<div>";
	for (var i = 0; i < this.options.length; ++i) {
		
		if (i != 0) {
			output += "<hr/>";
		}
		
		output += this.options[i] + " ";
		
		// add value selector
		var thevalues = npcutil.clone(this.values);
		if (this.isanimalint(this.options[i])) {
			if (this.values[1] == 9) { //inferior
				thevalues = [2, 1];
			} else { //superior
				thevalues = [2, 3, 4, 5, 6];
			}
		}
		output += npcutil.getListSelector("qval-"+i, thevalues, false, this.uses[i][1]);
		
	}
	return output;
};

AttrEDQuality.prototype.updatefromform = function(formDivId) {
	for (var i = 0; i < this.options.length; ++i) {	
		this.uses[i][1] = $("#"+formDivId+" #qval-"+i).val();
	}
};

AttrEDQuality.prototype.parse = function(text) {
	if (text.indexOf("(") > 0) {
		// add comma delimited items to this.uses in name,value pairs
		var uses = text.substring(text.indexOf("(")+1, text.indexOf(")")).split(/\s*,\s+/g);
		for (var i = 0; i < uses.length; ++i) {
			var usetext = uses[i].trim();
			var splitpoint = usetext.lastIndexOf(" ");
			var stat = usetext.substring(0,splitpoint).trim();
			var rating = usetext.substring(splitpoint).trim();
			
			for (var u = 0; u < this.uses.length; ++u) {
				var name = this.uses[u][0];
				if (name.toLowerCase() == stat.toLowerCase()) {
					this.uses[u][1] = rating;
				}
			}
		}
	}
	this.setdetails();
};

// class for origin qualities, essentially is it a custom DQuality with maxuses equal to 1
// with optional extra attribute modifiers
function OriginQuality(name, xp, statmods, extra) {
	this.base = DQuality;	
	this.base(name, xp, null, null, 1);
	if (statmods) {
		this.statmods = statmods;
	} else {
		this.statmods = [0, 0, 0, 0, 0, 0];
	}
	if (extra) {
		this.extra = extra;
	} else {
		this.extra = "";
	}		
}

OriginQuality.prototype = new DQuality();

OriginQuality.prototype.clone = function() {
	var clone = new OriginQuality(this.name, this.xp, this.statmods, this.extra);
	clone.details = this.details;
	clone.uses = this.uses;
	return clone;
}

// displays the edit form
OriginQuality.prototype.edit = function() {
	var output = "<div>";
	
	// if options provide a selector else provide a textbox
	var input;
	var id = "quse";
	// select current values
	var selected = null;
	if (this.uses.length > 0) {
		selected = this.uses[0];
	}
	
	output += "<input id='quse' type='text";
	// set current value	
	if (selected !== null) {
		output += "' value='" + selected;
	}
	output += "'/>";
	
	output += "<hr/>";
	
	// stat options
	for (var a = 0; a < 6; ++a) {
		if (a == 3) {
			output += "<br class='fatbreak'/>";
		}
		output += config.attributes[a] + " ";
		output += npcutil.getNumericSelector("attval-"+a, -5, 5, this.statmods[a]);
	}
	
	output += "<hr/>";
	
	// extra options
	output += "Extra: ";
	output += "<input id='qextra' type='text";
	// set current value	
	if (this.extra !== null) {
		output += "' value='" + this.extra;
	}
	output += "'/>";
		
	return output;
};

// updates with values from the edit form
OriginQuality.prototype.updatefromform = function(formDivId) {
	if ($("#"+formDivId+" #quse").length) {
		this.uses[0] = $("#"+formDivId+" #quse").val();
	}
	for (var a = 0; a < 6; ++a) {
		var attid = "attval-"+a;
		this.statmods[a] = parseInt($("#"+formDivId+" #"+attid).val());
	}
	if ($("#"+formDivId+" #quse").length) {
		this.extra = $("#"+formDivId+" #qextra").val();
	}
};

OriginQuality.prototype.makeused = function() {
	//if no uses
	if (this.uses.length === 0) {
		//set one useade with first option if there else dummy text
		if (this.options !== null && this.options.length > 0) {
			this.uses.push(this.options[0]);
		} else {
			this.uses.push("unspecified");
		}
	}
	if (this.statmods == null || typeof(this.statmods) == 'undefined') {
		this.statmods = [0, 0, 0, 0, 0, 0];
	}
	if (this.extra == null) {
		this.extra = "";
	}
};

// sets how the quality is displayed
OriginQuality.prototype.setdetails = function() {
	this.details = npcutil.sanitizeCustomText(this.uses[0]);
	// add stat mods
	var isfirst = true;
	for (var a = 0; a < 6; ++a) {
		if (this.statmods[a] != 0) {
			if (isfirst) {
				this.details += " ~ ";
				isfirst = false;
			} else {
				this.details += ", ";
			}
			this.details += config.attributes[a] + " ";
			if (this.statmods[a] >= 0) {
				this.details += "+";
			}
			this.details += this.statmods[a];
		}
	}
	// extra
	if (this.extra != null && this.extra.trim() != "") {
		this.details += " ~ " + npcutil.sanitizeCustomText(this.extra);
	}
};

// reads the quality
OriginQuality.prototype.parse = function(text) {	
	
	this.statmods = [0, 0, 0, 0, 0, 0];
	this.extra = "";
	// if there is a description
	if (text.indexOf("(") > 0) {
		// split by colon
		var parts = text.substring(text.indexOf("(")+1, text.indexOf(")")).split(/\s*~\s*/);
		// add first element as use
		this.uses = new Array();
		this.uses[0] = parts[0];
				
		if (parts.length > 1) {
			var attrparts = parts[1].split(/\s*,\s*/);
			for (var i = 0; i < attrparts.length; ++i) {
				var attrpart = attrparts[i].trim()
				// get first three characters and match to attribute
				var attribute = attrpart.substring(0,3);
				var mod = parseInt(attrpart.substring(3).trim());
				for (var a = 0; a < 6; ++a) {
					if (attribute == config.attributes[a]) {
						this.statmods[a] = mod;
					}
				}
			}
		}
		
		// extra
		if (parts.length > 2) {
			this.extra = parts[2].trim();
		}
	}
	this.setdetails();
};

// valued simple quality
function VSQuality(name, restrictions, options) {
	this.base = SQuality;
	this.base(name, 0, restrictions, options);
	this.use = "";
}
VSQuality.prototype = new SQuality();


VSQuality.prototype.clone = function() {
	var clone = new VSQuality(this.name, this.restrictions, this.options);
	clone.use = this.use;
	clone.details = this.details;
	return clone;
};

SQuality.prototype.makeused = function() {
	//set uses to 1 if none
	if (this.use === "" && this.options) {
		this.use = this.options[0];
	}
};

VSQuality.prototype.edit = function() {
	var output = "<div>"
	if (this.options) {
		// if there is more than one option, allow selection
		output += npcutil.getListKeySelector("qopts", this.options, false, this.use);
	}
	output += "</div>";
	return output;
};

VSQuality.prototype.getxp = function() {
	if (this.options && this.use != "") {
		// get index of use in options
		var xp = this.options[this.use];
		return qualitymanager.fixXp(xp);
	} else {
		return 0;
	}
};


//variable detail quality
function VDQuality(name, restrictions, options, maxuses) {
	this.base = DQuality;
	this.base(name, 0, restrictions, options);
	this.maxuses = maxuses;
	if (maxuses === undefined || maxuses === null || maxuses === 0) {
	 this.maxuses = config.qualityDefaultMaxuses;
	}
	this.uses = [];
}
VDQuality.prototype = new DQuality();

VDQuality.prototype.clone = function() {
	var clone = new VDQuality(this.name, this.restrictions, this.options, this.maxuses);
	clone.details = this.details;
	clone.uses = this.uses;
	return clone;
}

VDQuality.prototype.edit = function() {
	var output = "<div>";
	
	for (var i = 0; i < this.maxuses; ++i) {
		
		if (i != 0) {
			output += "<hr/>";	
		}
				
		// if options provide a selector else provide a textbox
		var input;
		var id = "quse-"+i;
		// select current values
		var selected = null;
		if (i < this.uses.length) {
			selected = this.uses[i];
		}
		
		output += npcutil.getListKeySelector(id, this.options, true, selected);
	}
	
	output += "</div>";
	return output;
};

VDQuality.prototype.makeused = function() {
	//if no uses
	if (this.uses.length === 0) {
		this.uses.push(this.options[0]);
	}
};

VDQuality.prototype.getxp = function() {
	var xp = 0;
	for (var u = 0; u < this.uses.length; ++u) {
		if (this.uses[u] !== "") {
			xp += this.options[this.uses[u]];
		}
	}
	return qualitymanager.fixXp(xp);
};

//variable extended detail quality
function VEDQuality(name, restrictions, options, maxuses, values) {
	this.base = EDQuality;
	this.base(name, 0, restrictions, options, maxuses);
	this.values = values;
	/*
	 * here each item in uses will itself be an array with two items. The first being
	 * the detail chosen the second being the value.
	 */
	this.uses = [];
}
VEDQuality.prototype = new EDQuality();

VEDQuality.prototype.clone = function() {
	var clone = new VEDQuality(this.name, this.restrictions, this.options, this.maxuses, this.values);
	clone.details = this.details;
	clone.uses = this.uses;
	return clone;
}

VEDQuality.prototype.makeused = function() {
	//if no uses
	if (this.uses.length === 0) {
		//set one useage with first option and first value if there else dummy text
		if (this.options !== null && this.options.length > 0) {
			this.uses.push([this.options[0], this.values[0]]);
		} else {
			this.uses.push(["unspecified", this.values[0]]);
		}
	}
};

VEDQuality.prototype.getxp = function() {
	var xp = 0;
	for (var u = 0; u < this.uses.length; ++u) {
		var name = this.uses[u][0];
		var value = this.uses[u][1];
		if (name !== "") {
			xp += this.values[value];
		}
	}
	return qualitymanager.fixXp(xp);
};

VEDQuality.prototype.edit = function() {
	var output = "<div>";
		
	for (var i = 0; i < this.maxuses; ++i) {	
			
		if (i += 0) {
			output += "<hr/>";
		}
			
		// if options provide a selector else provide a textbox
		var input;
		var id = "quse-"+i;
		// select current values
		var selected = null;
		if (i < this.uses.length) {
			selected = this.uses[i];
		}
		
		if (this.options && this.options.length > 0) {
			if (selected !== null) {
				output += npcutil.getListSelector(id, this.options, true, selected[0]);
			} else {
				output += npcutil.getListSelector(id, this.options, true);
			}
		} else {
			output += "<input type='text' id='"+id;
			
			if (selected !== null) {
				output += "' value='" + selected[0];
			}
			output += "'>";
		}
		
		// add value selector
		var select = document.createElement('select');
		select.id = "qval-"+i;
		if (selected !== null) {
			output += npcutil.getListKeySelector("qval-"+i, this.values, false, selected[1]);
		} else {
			output += npcutil.getListKeySelector("qval-"+i, this.values, false);
		}
		
	}
	
	output += "</div>";
	
	return output;
};
